Module: Google::Apis::SaasservicemgmtV1

Defined in:
lib/google/apis/saasservicemgmt_v1.rb,
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/service.rb,
lib/google/apis/saasservicemgmt_v1/gem_version.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

App Lifecycle Manager API

Model, deploy, and operate your SaaS at scale.

Defined Under Namespace

Classes: Aggregate, Blueprint, Dependency, Deprovision, Empty, ErrorBudget, FlagUpdate, FromMapping, GoogleCloudLocationLocation, ListLocationsResponse, ListReleasesResponse, ListRolloutKindsResponse, ListRolloutsResponse, ListSaasResponse, ListTenantsResponse, ListUnitKindsResponse, ListUnitOperationsResponse, ListUnitsResponse, Location, MaintenanceSettings, Provision, Release, ReleaseRequirements, Rollout, RolloutControl, RolloutKind, RolloutStats, RunRolloutActionParams, SaaSServiceManagementService, Saas, SaasCondition, Schedule, Status, Tenant, ToMapping, Unit, UnitCondition, UnitDependency, UnitKind, UnitOperation, UnitOperationCondition, UnitVariable, Upgrade, VariableMapping

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-saasservicemgmt_v1 gem

"0.3.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260415"
VERSION =

Version of the App Lifecycle Manager API this client connects to. This is NOT the gem version.

'V1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'