Class: Google::Apis::SaasservicemgmtV1::FromMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Output variables whose values will be passed on to dependencies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FromMapping

Returns a new instance of FromMapping.



206
207
208
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependencyString

Required. Alias of the dependency that the outputVariable will pass its value to Corresponds to the JSON property dependency

Returns:

  • (String)


199
200
201
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 199

def dependency
  @dependency
end

#output_variableString

Required. Name of the outputVariable on the dependency Corresponds to the JSON property outputVariable

Returns:

  • (String)


204
205
206
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 204

def output_variable
  @output_variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



211
212
213
214
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 211

def update!(**args)
  @dependency = args[:dependency] if args.key?(:dependency)
  @output_variable = args[:output_variable] if args.key?(:output_variable)
end