Class: Google::Apis::SaasservicemgmtV1::ListRolloutKindsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ListRolloutKindsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
The response structure for the ListRolloutKinds method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListRolloutKinds call to list the next page.
-
#rollout_kinds ⇒ Array<Google::Apis::SaasservicemgmtV1::RolloutKind>
The resulting rollout kinds.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRolloutKindsResponse
constructor
A new instance of ListRolloutKindsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRolloutKindsResponse
Returns a new instance of ListRolloutKindsResponse.
341 342 343 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListRolloutKinds call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
329 330 331 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 329 def next_page_token @next_page_token end |
#rollout_kinds ⇒ Array<Google::Apis::SaasservicemgmtV1::RolloutKind>
The resulting rollout kinds.
Corresponds to the JSON property rolloutKinds
334 335 336 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 334 def rollout_kinds @rollout_kinds end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
339 340 341 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 339 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
346 347 348 349 350 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 346 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rollout_kinds = args[:rollout_kinds] if args.key?(:rollout_kinds) @unreachable = args[:unreachable] if args.key?(:unreachable) end |