Class: Google::Apis::SaasservicemgmtV1::ListRolloutsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ListRolloutsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
The response structure for the ListRollouts method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListRollouts call to list the next page.
-
#rollouts ⇒ Array<Google::Apis::SaasservicemgmtV1::Rollout>
The resulting rollouts.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRolloutsResponse
constructor
A new instance of ListRolloutsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRolloutsResponse
Returns a new instance of ListRolloutsResponse.
373 374 375 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListRollouts
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
361 362 363 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 361 def next_page_token @next_page_token end |
#rollouts ⇒ Array<Google::Apis::SaasservicemgmtV1::Rollout>
The resulting rollouts.
Corresponds to the JSON property rollouts
366 367 368 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 366 def rollouts @rollouts end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
371 372 373 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 371 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
378 379 380 381 382 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 378 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rollouts = args[:rollouts] if args.key?(:rollouts) @unreachable = args[:unreachable] if args.key?(:unreachable) end |