Class: Google::Apis::SaasservicemgmtV1::ListSaasReleasesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ListSaasReleasesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
The response structure for the ListSaasReleases method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListSaasReleases call to list the next page.
-
#saas_releases ⇒ Array<Google::Apis::SaasservicemgmtV1::SaasRelease>
The resulting saas releases.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSaasReleasesResponse
constructor
A new instance of ListSaasReleasesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSaasReleasesResponse
Returns a new instance of ListSaasReleasesResponse.
461 462 463 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent
ListSaasReleases call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
449 450 451 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 449 def next_page_token @next_page_token end |
#saas_releases ⇒ Array<Google::Apis::SaasservicemgmtV1::SaasRelease>
The resulting saas releases.
Corresponds to the JSON property saasReleases
454 455 456 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 454 def saas_releases @saas_releases end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
459 460 461 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 459 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
466 467 468 469 470 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 466 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @saas_releases = args[:saas_releases] if args.key?(:saas_releases) @unreachable = args[:unreachable] if args.key?(:unreachable) end |