Class: Google::Apis::SaasservicemgmtV1::ListSaasResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ListSaasResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
The response structure for the ListSaas method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListSaas call to list the next page.
-
#saas ⇒ Array<Google::Apis::SaasservicemgmtV1::Saas>
The resulting saas.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSaasResponse
constructor
A new instance of ListSaasResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSaasResponse
Returns a new instance of ListSaasResponse.
405 406 407 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListSaas call
to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
393 394 395 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 393 def next_page_token @next_page_token end |
#saas ⇒ Array<Google::Apis::SaasservicemgmtV1::Saas>
The resulting saas.
Corresponds to the JSON property saas
398 399 400 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 398 def saas @saas end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
403 404 405 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 403 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
410 411 412 413 414 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 410 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @saas = args[:saas] if args.key?(:saas) @unreachable = args[:unreachable] if args.key?(:unreachable) end |