Class: Google::Apis::SaasservicemgmtV1::ListTenantsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ListTenantsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
The response structure for the ListTenants method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListTenants call to list the next page.
-
#tenants ⇒ Array<Google::Apis::SaasservicemgmtV1::Tenant>
The resulting tenants.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTenantsResponse
constructor
A new instance of ListTenantsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTenantsResponse
Returns a new instance of ListTenantsResponse.
437 438 439 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListTenants
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
425 426 427 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 425 def next_page_token @next_page_token end |
#tenants ⇒ Array<Google::Apis::SaasservicemgmtV1::Tenant>
The resulting tenants.
Corresponds to the JSON property tenants
430 431 432 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 430 def tenants @tenants end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
435 436 437 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 435 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
442 443 444 445 446 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 442 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tenants = args[:tenants] if args.key?(:tenants) @unreachable = args[:unreachable] if args.key?(:unreachable) end |