Class: Google::Apis::SaasservicemgmtV1::ListUnitGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ListUnitGroupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
The response structure for the ListUnitGroups method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnitGroups call to list the next page.
-
#unit_groups ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitGroup>
The resulting unit groups.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListUnitGroupsResponse
constructor
A new instance of ListUnitGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListUnitGroupsResponse
Returns a new instance of ListUnitGroupsResponse.
590 591 592 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If present, the next page token can be provided to a subsequent ListUnitGroups
call to list the next page. If empty, there are no more pages.
Corresponds to the JSON property nextPageToken
578 579 580 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 578 def next_page_token @next_page_token end |
#unit_groups ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitGroup>
The resulting unit groups.
Corresponds to the JSON property unitGroups
583 584 585 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 583 def unit_groups @unit_groups end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
588 589 590 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 588 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
595 596 597 598 599 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 595 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unit_groups = args[:unit_groups] if args.key?(:unit_groups) @unreachable = args[:unreachable] if args.key?(:unreachable) end |