Class: Google::Apis::SaasservicemgmtV1::MaintenanceSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Captures requested directives for performing future maintenance on the unit. This includes a request for the unit to skip maintenance for a period of time and remain pinned to its current release as well as controls for postponing maintenance scheduled in future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceSettings

Returns a new instance of MaintenanceSettings.



635
636
637
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pinned_until_timeString

Optional. If present, it fixes the release on the unit until the given time; i. e. changes to the release field will be rejected. Rollouts should and will also respect this by not requesting an upgrade in the first place. Corresponds to the JSON property pinnedUntilTime

Returns:

  • (String)


633
634
635
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 633

def pinned_until_time
  @pinned_until_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



640
641
642
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 640

def update!(**args)
  @pinned_until_time = args[:pinned_until_time] if args.key?(:pinned_until_time)
end