Class: Google::Apis::SaasservicemgmtV1::Release
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Release
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
A new version to be propagated and deployed to units. This includes pointers to packaged blueprints for actuation (e.g Helm or Terraform configuration packages) via artifact registry.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#blueprint ⇒ Google::Apis::SaasservicemgmtV1::Blueprint
Blueprints are OCI Images that contain all of the artifacts needed to provision a unit.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#input_variable_defaults ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional.
-
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#output_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional.
-
#release_requirements ⇒ Google::Apis::SaasservicemgmtV1::ReleaseRequirements
Set of requirements to be fulfilled on the Unit when using this Release.
-
#uid ⇒ String
Output only.
-
#unit_kind ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Release
constructor
A new instance of Release.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Release
Returns a new instance of Release.
764 765 766 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
684 685 686 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 684 def annotations @annotations end |
#blueprint ⇒ Google::Apis::SaasservicemgmtV1::Blueprint
Blueprints are OCI Images that contain all of the artifacts needed to
provision a unit. Metadata such as, type of the engine used to actuate the
blueprint (e.g. terraform, helm etc) and version will come from the image
manifest. If the hostname is omitted, it will be assumed to be the regional
path to Artifact Registry (eg. us-east1-docker.pkg.dev).
Corresponds to the JSON property blueprint
693 694 695 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 693 def blueprint @blueprint end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
698 699 700 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 698 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
705 706 707 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 705 def etag @etag end |
#input_variable_defaults ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional. Mapping of input variables to default values. Maximum 100
Corresponds to the JSON property inputVariableDefaults
710 711 712 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 710 def input_variable_defaults @input_variable_defaults end |
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional. Output only. List of input variables declared on the blueprint and
can be present with their values on the unit spec
Corresponds to the JSON property inputVariables
716 717 718 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 716 def input_variables @input_variables end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
722 723 724 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 722 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/releases/
release"
Corresponds to the JSON property name
729 730 731 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 729 def name @name end |
#output_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional. Output only. List of output variables declared on the blueprint and
can be present with their values on the unit status
Corresponds to the JSON property outputVariables
735 736 737 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 735 def output_variables @output_variables end |
#release_requirements ⇒ Google::Apis::SaasservicemgmtV1::ReleaseRequirements
Set of requirements to be fulfilled on the Unit when using this Release.
Corresponds to the JSON property releaseRequirements
740 741 742 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 740 def release_requirements @release_requirements end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
749 750 751 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 749 def uid @uid end |
#unit_kind ⇒ String
Required. Immutable. Reference to the UnitKind this Release corresponds to (
required and immutable once created).
Corresponds to the JSON property unitKind
755 756 757 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 755 def unit_kind @unit_kind end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
762 763 764 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 762 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 769 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @blueprint = args[:blueprint] if args.key?(:blueprint) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @input_variable_defaults = args[:input_variable_defaults] if args.key?(:input_variable_defaults) @input_variables = args[:input_variables] if args.key?(:input_variables) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @output_variables = args[:output_variables] if args.key?(:output_variables) @release_requirements = args[:release_requirements] if args.key?(:release_requirements) @uid = args[:uid] if args.key?(:uid) @unit_kind = args[:unit_kind] if args.key?(:unit_kind) @update_time = args[:update_time] if args.key?(:update_time) end |