Class: Google::Apis::SaasservicemgmtV1::SaasCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

SaasCondition describes the status of a Saas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SaasCondition

Returns a new instance of SaasCondition.



1430
1431
1432
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


1408
1409
1410
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1408

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1413

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


1418
1419
1420
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1418

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


1423
1424
1425
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1423

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


1428
1429
1430
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1428

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1435
1436
1437
1438
1439
1440
1441
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1435

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end