Class: Google::Apis::SaasservicemgmtV1::ToMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Input variables whose values will be passed on to dependencies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToMapping

Returns a new instance of ToMapping.



1686
1687
1688
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependencyString

Required. Alias of the dependency that the inputVariable will pass its value to Corresponds to the JSON property dependency

Returns:

  • (String)


1672
1673
1674
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1672

def dependency
  @dependency
end

#ignore_for_lookupBoolean Also known as: ignore_for_lookup?

Optional. Tells App Lifecycle Manager if this mapping should be used during lookup or not Corresponds to the JSON property ignoreForLookup

Returns:

  • (Boolean)


1678
1679
1680
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1678

def ignore_for_lookup
  @ignore_for_lookup
end

#input_variableString

Required. Name of the inputVariable on the dependency Corresponds to the JSON property inputVariable

Returns:

  • (String)


1684
1685
1686
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1684

def input_variable
  @input_variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1691
1692
1693
1694
1695
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1691

def update!(**args)
  @dependency = args[:dependency] if args.key?(:dependency)
  @ignore_for_lookup = args[:ignore_for_lookup] if args.key?(:ignore_for_lookup)
  @input_variable = args[:input_variable] if args.key?(:input_variable)
end