Class: Google::Apis::SaasservicemgmtV1::Unit
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Unit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
A unit of deployment that has its lifecycle via a CRUD API using an actuation engine under the hood (e.g. based on Terraform, Helm or a custom implementation provided by a service producer). A building block of a SaaS Tenant.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitCondition>
Optional.
-
#create_time ⇒ String
Output only.
-
#dependencies ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitDependency>
Optional.
-
#dependents ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitDependency>
Optional.
-
#etag ⇒ String
Output only.
-
#flag_revisions ⇒ Array<String>
Optional.
-
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#maintenance ⇒ Google::Apis::SaasservicemgmtV1::MaintenanceSettings
Captures requested directives for performing future maintenance on the unit.
-
#management_mode ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#ongoing_operations ⇒ Array<String>
Optional.
-
#output_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional.
-
#pending_operations ⇒ Array<String>
Optional.
-
#release ⇒ String
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduled_operations ⇒ Array<String>
Optional.
-
#state ⇒ String
Optional.
-
#system_cleanup_at ⇒ String
Optional.
-
#system_managed_state ⇒ String
Optional.
-
#tenant ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#unit_kind ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Unit
constructor
A new instance of Unit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Unit
Returns a new instance of Unit.
1699 1700 1701 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1543 1544 1545 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1543 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitCondition>
Optional. Output only. A set of conditions which indicate the various
conditions this resource can have.
Corresponds to the JSON property conditions
1549 1550 1551 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1549 def conditions @conditions end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1554 1555 1556 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1554 def create_time @create_time end |
#dependencies ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitDependency>
Optional. Output only. Set of dependencies for this unit. Maximum 10.
Corresponds to the JSON property dependencies
1559 1560 1561 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1559 def dependencies @dependencies end |
#dependents ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitDependency>
Optional. Output only. List of Units that depend on this unit. Unit can only
be deprovisioned if this list is empty. Maximum 1000.
Corresponds to the JSON property dependents
1565 1566 1567 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1565 def dependents @dependents end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1572 1573 1574 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1572 def etag @etag end |
#flag_revisions ⇒ Array<String>
Optional. Output only. Flag revisions used by this Unit.
Corresponds to the JSON property flagRevisions
1577 1578 1579 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1577 def flag_revisions @flag_revisions end |
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional. Output only. Indicates the current input variables deployed by the
unit
Corresponds to the JSON property inputVariables
1583 1584 1585 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1583 def input_variables @input_variables end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1589 1590 1591 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1589 def labels @labels end |
#maintenance ⇒ Google::Apis::SaasservicemgmtV1::MaintenanceSettings
Captures requested directives for performing future maintenance on the unit.
This includes a request for the unit to skip maintenance for a period of time
and remain pinned to its current release as well as controls for postponing
maintenance scheduled in future.
Corresponds to the JSON property maintenance
1597 1598 1599 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1597 def maintenance @maintenance end |
#management_mode ⇒ String
Optional. Immutable. Indicates whether the Unit life cycle is controlled by
the user or by the system. Immutable once created.
Corresponds to the JSON property managementMode
1603 1604 1605 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1603 def management_mode @management_mode end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/units/unit"
Corresponds to the JSON property name
1609 1610 1611 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1609 def name @name end |
#ongoing_operations ⇒ Array<String>
Optional. Output only. List of concurrent UnitOperations that are operating on
this Unit.
Corresponds to the JSON property ongoingOperations
1615 1616 1617 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1615 def ongoing_operations @ongoing_operations end |
#output_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional. Output only. Set of key/value pairs corresponding to output
variables from execution of actuation templates. The variables are declared in
actuation configs (e.g in helm chart or terraform) and the values are fetched
and returned by the actuation engine upon completion of execution.
Corresponds to the JSON property outputVariables
1623 1624 1625 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1623 def output_variables @output_variables end |
#pending_operations ⇒ Array<String>
Optional. Output only. List of pending (wait to be executed) UnitOperations
for this unit.
Corresponds to the JSON property pendingOperations
1629 1630 1631 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1629 def pending_operations @pending_operations end |
#release ⇒ String
Optional. Output only. The current Release object for this Unit.
Corresponds to the JSON property release
1634 1635 1636 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1634 def release @release end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1639 1640 1641 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1639 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Indicates whether the resource location satisfies Zone Separation
constraints. This is false by default.
Corresponds to the JSON property satisfiesPzs
1646 1647 1648 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1646 def satisfies_pzs @satisfies_pzs end |
#scheduled_operations ⇒ Array<String>
Optional. Output only. List of scheduled UnitOperations for this unit.
Corresponds to the JSON property scheduledOperations
1652 1653 1654 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1652 def scheduled_operations @scheduled_operations end |
#state ⇒ String
Optional. Output only. Current lifecycle state of the resource (e.g. if it's
being created or ready to use).
Corresponds to the JSON property state
1658 1659 1660 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1658 def state @state end |
#system_cleanup_at ⇒ String
Optional. Output only. If set, indicates the time when the system will start
removing the unit.
Corresponds to the JSON property systemCleanupAt
1664 1665 1666 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1664 def system_cleanup_at @system_cleanup_at end |
#system_managed_state ⇒ String
Optional. Output only. Indicates the system managed state of the unit.
Corresponds to the JSON property systemManagedState
1669 1670 1671 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1669 def system_managed_state @system_managed_state end |
#tenant ⇒ String
Optional. Reference to the Saas Tenant resource this unit belongs to. This for
example informs the maintenance policies to use for scheduling future updates
on a unit. (optional and immutable once created)
Corresponds to the JSON property tenant
1676 1677 1678 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1676 def tenant @tenant end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1685 1686 1687 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1685 def uid @uid end |
#unit_kind ⇒ String
Optional. Reference to the UnitKind this Unit belongs to. Immutable once set.
Corresponds to the JSON property unitKind
1690 1691 1692 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1690 def unit_kind @unit_kind end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1697 1698 1699 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1697 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1704 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @dependencies = args[:dependencies] if args.key?(:dependencies) @dependents = args[:dependents] if args.key?(:dependents) @etag = args[:etag] if args.key?(:etag) @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions) @input_variables = args[:input_variables] if args.key?(:input_variables) @labels = args[:labels] if args.key?(:labels) @maintenance = args[:maintenance] if args.key?(:maintenance) @management_mode = args[:management_mode] if args.key?(:management_mode) @name = args[:name] if args.key?(:name) @ongoing_operations = args[:ongoing_operations] if args.key?(:ongoing_operations) @output_variables = args[:output_variables] if args.key?(:output_variables) @pending_operations = args[:pending_operations] if args.key?(:pending_operations) @release = args[:release] if args.key?(:release) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduled_operations = args[:scheduled_operations] if args.key?(:scheduled_operations) @state = args[:state] if args.key?(:state) @system_cleanup_at = args[:system_cleanup_at] if args.key?(:system_cleanup_at) @system_managed_state = args[:system_managed_state] if args.key?(:system_managed_state) @tenant = args[:tenant] if args.key?(:tenant) @uid = args[:uid] if args.key?(:uid) @unit_kind = args[:unit_kind] if args.key?(:unit_kind) @update_time = args[:update_time] if args.key?(:update_time) end |