Class: Google::Apis::SaasservicemgmtV1::UnitCondition
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::UnitCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
UnitCondition describes the status of an Unit. UnitCondition is individual components that contribute to an overall state.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Required.
-
#message ⇒ String
Required.
-
#reason ⇒ String
Required.
-
#status ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitCondition
constructor
A new instance of UnitCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitCondition
Returns a new instance of UnitCondition.
1938 1939 1940 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Required. Last time the condition transited from one status to another.
Corresponds to the JSON property lastTransitionTime
1916 1917 1918 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1916 def last_transition_time @last_transition_time end |
#message ⇒ String
Required. Human readable message indicating details about the last transition.
Corresponds to the JSON property message
1921 1922 1923 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1921 def @message end |
#reason ⇒ String
Required. Brief reason for the condition's last transition.
Corresponds to the JSON property reason
1926 1927 1928 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1926 def reason @reason end |
#status ⇒ String
Required. Status of the condition.
Corresponds to the JSON property status
1931 1932 1933 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1931 def status @status end |
#type ⇒ String
Required. Type of the condition.
Corresponds to the JSON property type
1936 1937 1938 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1936 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1943 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |