Class: Google::Apis::SaasservicemgmtV1::UnitGroupOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

UnitGroupOperation represents an operation on a UnitGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitGroupOperation

Returns a new instance of UnitGroupOperation.



2101
2102
2103
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


2058
2059
2060
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2058

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2063
2064
2065
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2063

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


2070
2071
2072
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2070

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2076
2077
2078
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2076

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/ unitGroupOperations/unitGroupOperation" Corresponds to the JSON property name

Returns:

  • (String)


2083
2084
2085
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2083

def name
  @name
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


2092
2093
2094
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2092

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


2099
2100
2101
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2099

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2106
2107
2108
2109
2110
2111
2112
2113
2114
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2106

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end