Class: Google::Apis::SaasservicemgmtV1::UnitKind

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Definition of a Unit. Units belonging to the same UnitKind are managed together; for example they follow the same release model (blueprints, versions etc.) and are typically rolled out together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitKind

Returns a new instance of UnitKind.



1903
1904
1905
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1815
1816
1817
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1815

def annotations
  @annotations
end

#boundary_typeString

Optional. Output only. BoundaryType describes the type of boundary the Unit Kind represents. Corresponds to the JSON property boundaryType

Returns:

  • (String)


1821
1822
1823
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1821

def boundary_type
  @boundary_type
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1826
1827
1828
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1826

def create_time
  @create_time
end

#default_flag_revisionsArray<String>

Optional. Default revisions of flags for this UnitKind. Newly created units will use the flag default_flag_revisions present at the time of creation. Corresponds to the JSON property defaultFlagRevisions

Returns:

  • (Array<String>)


1832
1833
1834
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1832

def default_flag_revisions
  @default_flag_revisions
end

#default_releaseString

Optional. A reference to the Release object to use as default for creating new units of this UnitKind (optional). If not specified, a new unit must explicitly reference which release to use for its creation. Corresponds to the JSON property defaultRelease

Returns:

  • (String)


1839
1840
1841
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1839

def default_release
  @default_release
end

#dependenciesArray<Google::Apis::SaasservicemgmtV1::Dependency>

Optional. Immutable. List of other unit kinds that this release will depend on. Dependencies will be automatically provisioned if not found. Maximum 10. Corresponds to the JSON property dependencies



1845
1846
1847
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1845

def dependencies
  @dependencies
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


1852
1853
1854
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1852

def etag
  @etag
end

#input_variable_mappingsArray<Google::Apis::SaasservicemgmtV1::VariableMapping>

Optional. List of inputVariables for this release that will either be retrieved from a dependency's outputVariables, or will be passed on to a dependency's inputVariables. Maximum 100. Corresponds to the JSON property inputVariableMappings



1859
1860
1861
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1859

def input_variable_mappings
  @input_variable_mappings
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1865
1866
1867
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1865

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/unitKinds/ unitKind" Corresponds to the JSON property name

Returns:

  • (String)


1872
1873
1874
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1872

def name
  @name
end

#output_variable_mappingsArray<Google::Apis::SaasservicemgmtV1::VariableMapping>

Optional. List of outputVariables for this unit kind will be passed to this unit's outputVariables. Maximum 100. Corresponds to the JSON property outputVariableMappings



1878
1879
1880
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1878

def output_variable_mappings
  @output_variable_mappings
end

#saasString

Required. Immutable. A reference to the Saas that defines the product (managed service) that the producer wants to manage with App Lifecycle Manager. Part of the App Lifecycle Manager common data model. Immutable once set. Corresponds to the JSON property saas

Returns:

  • (String)


1885
1886
1887
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1885

def saas
  @saas
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1894

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


1901
1902
1903
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1901

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1908

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @boundary_type = args[:boundary_type] if args.key?(:boundary_type)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_flag_revisions = args[:default_flag_revisions] if args.key?(:default_flag_revisions)
  @default_release = args[:default_release] if args.key?(:default_release)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @etag = args[:etag] if args.key?(:etag)
  @input_variable_mappings = args[:input_variable_mappings] if args.key?(:input_variable_mappings)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @output_variable_mappings = args[:output_variable_mappings] if args.key?(:output_variable_mappings)
  @saas = args[:saas] if args.key?(:saas)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end