Class: Google::Apis::SaasservicemgmtV1::UnitOperationCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

UnitOperationCondition describes the status of an Unit Operation. UnitOperationCondition is individual components that contribute to an overall state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitOperationCondition

Returns a new instance of UnitOperationCondition.



2133
2134
2135
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


2111
2112
2113
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2111

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


2116
2117
2118
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2116

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


2121
2122
2123
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2121

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


2126
2127
2128
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2126

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


2131
2132
2133
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2131

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2138
2139
2140
2141
2142
2143
2144
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2138

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end