Class: Google::Apis::SaasservicemgmtV1::UnitUpdatePacing
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::UnitUpdatePacing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
UnitUpdatePacing defines the policy for the maximum number of unit operations that can run for a rollout in parallel in a single region.
Instance Attribute Summary collapse
-
#max_concurrent_operations_count ⇒ Fixnum
Optional.
-
#max_concurrent_operations_percent ⇒ Google::Apis::SaasservicemgmtV1::Decimal
A representation of a decimal value, such as 2.5.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitUpdatePacing
constructor
A new instance of UnitUpdatePacing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitUpdatePacing
Returns a new instance of UnitUpdatePacing.
2166 2167 2168 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_concurrent_operations_count ⇒ Fixnum
Optional. An absolute cap on concurrent units operations. If both percent and
count are provided, the system uses the MINIMUM (most restrictive).
Corresponds to the JSON property maxConcurrentOperationsCount
2156 2157 2158 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2156 def max_concurrent_operations_count @max_concurrent_operations_count end |
#max_concurrent_operations_percent ⇒ Google::Apis::SaasservicemgmtV1::Decimal
A representation of a decimal value, such as 2.5. Clients may convert values
into language-native decimal formats, such as Java's BigDecimal or
Python's decimal.Decimal.
Corresponds to the JSON property maxConcurrentOperationsPercent
2164 2165 2166 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2164 def max_concurrent_operations_percent @max_concurrent_operations_percent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2171 2172 2173 2174 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2171 def update!(**args) @max_concurrent_operations_count = args[:max_concurrent_operations_count] if args.key?(:max_concurrent_operations_count) @max_concurrent_operations_percent = args[:max_concurrent_operations_percent] if args.key?(:max_concurrent_operations_percent) end |