Class: Google::Apis::SaasservicemgmtV1::Aggregate
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Aggregate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Represents the aggregation of a set of population of like records by a certain group. For example, a collection of unit counts can be aggregated and grouped by their state.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Required.
-
#group ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Aggregate
constructor
A new instance of Aggregate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Aggregate
Returns a new instance of Aggregate.
41 42 43 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 41 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Required. Number of records in the group.
Corresponds to the JSON property count
34 35 36 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 34 def count @count end |
#group ⇒ String
Required. Group by which to aggregate.
Corresponds to the JSON property group
39 40 41 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 39 def group @group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46 47 48 49 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 46 def update!(**args) @count = args[:count] if args.key?(:count) @group = args[:group] if args.key?(:group) end |