Class: Google::Apis::SaasservicemgmtV1::MaintenanceSettings
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::MaintenanceSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Captures requested directives for performing future maintenance on the unit. This includes a request for the unit to skip maintenance for a period of time and remain pinned to its current release as well as controls for postponing maintenance scheduled in future.
Instance Attribute Summary collapse
-
#pinned_until_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenanceSettings
constructor
A new instance of MaintenanceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenanceSettings
Returns a new instance of MaintenanceSettings.
579 580 581 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pinned_until_time ⇒ String
Optional. If present, it fixes the release on the unit until the given time; i.
e. changes to the release field will be rejected. Rollouts should and will
also respect this by not requesting an upgrade in the first place.
Corresponds to the JSON property pinnedUntilTime
577 578 579 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 577 def pinned_until_time @pinned_until_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
584 585 586 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 584 def update!(**args) @pinned_until_time = args[:pinned_until_time] if args.key?(:pinned_until_time) end |