Class: Google::Apis::SaasservicemgmtV1::Release

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

A new version to be propagated and deployed to units. This includes pointers to packaged blueprints for actuation (e.g Helm or Terraform configuration packages) via artifact registry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Release

Returns a new instance of Release.



708
709
710
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


628
629
630
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 628

def annotations
  @annotations
end

#blueprintGoogle::Apis::SaasservicemgmtV1::Blueprint

Blueprints are OCI Images that contain all of the artifacts needed to provision a unit. Metadata such as, type of the engine used to actuate the blueprint (e.g. terraform, helm etc) and version will come from the image manifest. If the hostname is omitted, it will be assumed to be the regional path to Artifact Registry (eg. us-east1-docker.pkg.dev). Corresponds to the JSON property blueprint



637
638
639
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 637

def blueprint
  @blueprint
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


642
643
644
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 642

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 649

def etag
  @etag
end

#input_variable_defaultsArray<Google::Apis::SaasservicemgmtV1::UnitVariable>

Optional. Mapping of input variables to default values. Maximum 100 Corresponds to the JSON property inputVariableDefaults



654
655
656
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 654

def input_variable_defaults
  @input_variable_defaults
end

#input_variablesArray<Google::Apis::SaasservicemgmtV1::UnitVariable>

Optional. Output only. List of input variables declared on the blueprint and can be present with their values on the unit spec Corresponds to the JSON property inputVariables



660
661
662
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 660

def input_variables
  @input_variables
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


666
667
668
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 666

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/releases/ release" Corresponds to the JSON property name

Returns:

  • (String)


673
674
675
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 673

def name
  @name
end

#output_variablesArray<Google::Apis::SaasservicemgmtV1::UnitVariable>

Optional. Output only. List of output variables declared on the blueprint and can be present with their values on the unit status Corresponds to the JSON property outputVariables



679
680
681
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 679

def output_variables
  @output_variables
end

#release_requirementsGoogle::Apis::SaasservicemgmtV1::ReleaseRequirements

Set of requirements to be fulfilled on the Unit when using this Release. Corresponds to the JSON property releaseRequirements



684
685
686
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 684

def release_requirements
  @release_requirements
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


693
694
695
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 693

def uid
  @uid
end

#unit_kindString

Required. Immutable. Reference to the UnitKind this Release corresponds to ( required and immutable once created). Corresponds to the JSON property unitKind

Returns:

  • (String)


699
700
701
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 699

def unit_kind
  @unit_kind
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


706
707
708
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 706

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 713

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @blueprint = args[:blueprint] if args.key?(:blueprint)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @input_variable_defaults = args[:input_variable_defaults] if args.key?(:input_variable_defaults)
  @input_variables = args[:input_variables] if args.key?(:input_variables)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @output_variables = args[:output_variables] if args.key?(:output_variables)
  @release_requirements = args[:release_requirements] if args.key?(:release_requirements)
  @uid = args[:uid] if args.key?(:uid)
  @unit_kind = args[:unit_kind] if args.key?(:unit_kind)
  @update_time = args[:update_time] if args.key?(:update_time)
end