Class: Google::Apis::SaasservicemgmtV1::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Represents a single rollout execution and its results
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#control ⇒ Google::Apis::SaasservicemgmtV1::RolloutControl
RolloutControl provides a way to request a change to the execution of a Rollout by pausing or canceling it.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#effective_unit_filter ⇒ String
Optional.
-
#end_time ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#flag_release ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#parent_rollout ⇒ String
Optional.
-
#release ⇒ String
Optional.
-
#rollout_kind ⇒ String
Required.
-
#rollout_orchestration_strategy ⇒ String
Optional.
-
#root_rollout ⇒ String
Optional.
-
#start_time ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#state_message ⇒ String
Output only.
-
#state_transition_time ⇒ String
Optional.
-
#stats ⇒ Google::Apis::SaasservicemgmtV1::RolloutStats
RolloutStats contains information about the progress of a rollout.
-
#uid ⇒ String
Output only.
-
#unit_filter ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
971 972 973 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
817 818 819 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 817 def annotations @annotations end |
#control ⇒ Google::Apis::SaasservicemgmtV1::RolloutControl
RolloutControl provides a way to request a change to the execution of a
Rollout by pausing or canceling it.
Corresponds to the JSON property control
823 824 825 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 823 def control @control end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
828 829 830 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 828 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp when the resource was marked for deletion (deletion
is an asynchronous operation).
Corresponds to the JSON property deleteTime
834 835 836 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 834 def delete_time @delete_time end |
#effective_unit_filter ⇒ String
Optional. Output only. Output only snapshot of the effective unit filter at
Rollout start time. Contains a CEL(https://github.com/google/cel-spec)
expression consisting of a conjunction of Rollout.unit_filter and RolloutKind.
unit_filter. This field captures the filter applied by the Rollout to
determine the Unit population. If the associated RolloutKind's unit_filter is
modified after the rollout is started, it will not be updated here.
Corresponds to the JSON property effectiveUnitFilter
844 845 846 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 844 def effective_unit_filter @effective_unit_filter end |
#end_time ⇒ String
Optional. Output only. The time when the rollout finished execution (
regardless of success, failure, or cancellation). Will be empty if the rollout
hasn't finished yet. Once set, the rollout is in terminal state and all the
results are final.
Corresponds to the JSON property endTime
852 853 854 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 852 def end_time @end_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
859 860 861 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 859 def etag @etag end |
#flag_release ⇒ String
Optional. Immutable. Name of the FlagRelease to be rolled out to the target
Units. Release and FlagRelease are mutually exclusive. Note: release comment
needs to be adjusted to mention that "Release and FlagRelease are mutually
exclusive" when visibility restriction will be lifted.
Corresponds to the JSON property flagRelease
867 868 869 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 867 def flag_release @flag_release end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
873 874 875 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 873 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/rollout/
rollout_id"
Corresponds to the JSON property name
880 881 882 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 880 def name @name end |
#parent_rollout ⇒ String
Optional. Output only. The direct parent rollout that this rollout is stemming
from. The resource name (full URI of the resource) following the standard
naming scheme: "projects/project/locations/location/rollouts/rollout_id"
Corresponds to the JSON property parentRollout
887 888 889 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 887 def parent_rollout @parent_rollout end |
#release ⇒ String
Optional. Immutable. Name of the Release that gets rolled out to target Units.
Required if no other type of release is specified.
Corresponds to the JSON property release
893 894 895 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 893 def release @release end |
#rollout_kind ⇒ String
Required. Immutable. Name of the RolloutKind this rollout is stemming from and
adhering to.
Corresponds to the JSON property rolloutKind
899 900 901 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 899 def rollout_kind @rollout_kind end |
#rollout_orchestration_strategy ⇒ String
Optional. The strategy used for executing this Rollout. This strategy will
override whatever strategy is specified in the RolloutKind. If not specified
on creation, the strategy from RolloutKind will be used. There are two
supported values strategies which are used to control - "Google.Cloud.Simple.
AllAtOnce" - "Google.Cloud.Simple.OneLocationAtATime" A rollout with one of
these simple strategies will rollout across all locations defined in the
targeted UnitKind's Saas Locations.
Corresponds to the JSON property rolloutOrchestrationStrategy
910 911 912 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 910 def rollout_orchestration_strategy @rollout_orchestration_strategy end |
#root_rollout ⇒ String
Optional. Output only. The root rollout that this rollout is stemming from.
The resource name (full URI of the resource) following the standard naming
scheme: "projects/project/locations/location/rollouts/rollout_id"
Corresponds to the JSON property rootRollout
917 918 919 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 917 def root_rollout @root_rollout end |
#start_time ⇒ String
Optional. Output only. The time when the rollout started executing. Will be
empty if the rollout hasn't started yet.
Corresponds to the JSON property startTime
923 924 925 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 923 def start_time @start_time end |
#state ⇒ String
Output only. Current state of the rollout.
Corresponds to the JSON property state
928 929 930 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 928 def state @state end |
#state_message ⇒ String
Output only. Human readable message indicating details about the last state
transition.
Corresponds to the JSON property stateMessage
934 935 936 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 934 def @state_message end |
#state_transition_time ⇒ String
Optional. Output only. The time when the rollout transitioned into its current
state.
Corresponds to the JSON property stateTransitionTime
940 941 942 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 940 def state_transition_time @state_transition_time end |
#stats ⇒ Google::Apis::SaasservicemgmtV1::RolloutStats
RolloutStats contains information about the progress of a rollout.
Corresponds to the JSON property stats
945 946 947 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 945 def stats @stats end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
954 955 956 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 954 def uid @uid end |
#unit_filter ⇒ String
Optional. CEL(https://github.com/google/cel-spec) formatted filter string
against Unit. The filter will be applied to determine the eligible unit
population. This filter can only reduce, but not expand the scope of the
rollout. If not provided, the unit_filter from the RolloutKind will be used.
Corresponds to the JSON property unitFilter
962 963 964 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 962 def unit_filter @unit_filter end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
969 970 971 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 969 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 976 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @control = args[:control] if args.key?(:control) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @effective_unit_filter = args[:effective_unit_filter] if args.key?(:effective_unit_filter) @end_time = args[:end_time] if args.key?(:end_time) @etag = args[:etag] if args.key?(:etag) @flag_release = args[:flag_release] if args.key?(:flag_release) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent_rollout = args[:parent_rollout] if args.key?(:parent_rollout) @release = args[:release] if args.key?(:release) @rollout_kind = args[:rollout_kind] if args.key?(:rollout_kind) @rollout_orchestration_strategy = args[:rollout_orchestration_strategy] if args.key?(:rollout_orchestration_strategy) @root_rollout = args[:root_rollout] if args.key?(:root_rollout) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @state_transition_time = args[:state_transition_time] if args.key?(:state_transition_time) @stats = args[:stats] if args.key?(:stats) @uid = args[:uid] if args.key?(:uid) @unit_filter = args[:unit_filter] if args.key?(:unit_filter) @update_time = args[:update_time] if args.key?(:update_time) end |