Class: Google::Apis::SaasservicemgmtV1::RunRolloutActionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Parameters for the RUN action controlling the behavior of the rollout when it is resumed from a PAUSED state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunRolloutActionParams

Returns a new instance of RunRolloutActionParams.



1291
1292
1293
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retry_failed_operationsBoolean Also known as: retry_failed_operations?

Required. If true, the rollout will retry failed operations when resumed. This is applicable only the current state of the Rollout is PAUSED and the requested action is RUN. Corresponds to the JSON property retryFailedOperations

Returns:

  • (Boolean)


1288
1289
1290
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1288

def retry_failed_operations
  @retry_failed_operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1296
1297
1298
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1296

def update!(**args)
  @retry_failed_operations = args[:retry_failed_operations] if args.key?(:retry_failed_operations)
end