Class: Google::Apis::SaasservicemgmtV1::Saas
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Saas
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Saas is a representation of a SaaS service managed by the Producer.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::SaasCondition>
Output only.
-
#create_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::SaasservicemgmtV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::SaasservicemgmtV1::Location>
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Saas
constructor
A new instance of Saas.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Saas
Returns a new instance of Saas.
1284 1285 1286 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1214 1215 1216 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1214 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::SaasCondition>
Output only. A set of conditions which indicate the various conditions this
resource can have.
Corresponds to the JSON property conditions
1220 1221 1222 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1220 def conditions @conditions end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1225 1226 1227 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1225 def create_time @create_time end |
#error ⇒ Google::Apis::SaasservicemgmtV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1235 1236 1237 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1235 def error @error end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1242 1243 1244 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1242 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1248 1249 1250 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1248 def labels @labels end |
#locations ⇒ Array<Google::Apis::SaasservicemgmtV1::Location>
Optional. List of locations that the service is available in. Rollout refers
to the list to generate a rollout plan.
Corresponds to the JSON property locations
1254 1255 1256 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1254 def locations @locations end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/saas/saas"
Corresponds to the JSON property name
1260 1261 1262 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1260 def name @name end |
#state ⇒ String
Output only. State of the Saas. It is always in STATE_ACTIVE state if the
application_template is empty.
Corresponds to the JSON property state
1266 1267 1268 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1266 def state @state end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1275 1276 1277 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1275 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1282 1283 1284 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1282 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1289 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @error = args[:error] if args.key?(:error) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |