Class: Google::Apis::SaasservicemgmtV1::Saas

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Saas is a representation of a SaaS service managed by the Producer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Saas

Returns a new instance of Saas.



1381
1382
1383
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1311
1312
1313
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1311

def annotations
  @annotations
end

#conditionsArray<Google::Apis::SaasservicemgmtV1::SaasCondition>

Output only. A set of conditions which indicate the various conditions this resource can have. Corresponds to the JSON property conditions



1317
1318
1319
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1317

def conditions
  @conditions
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1322

def create_time
  @create_time
end

#errorGoogle::Apis::SaasservicemgmtV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1332
1333
1334
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1332

def error
  @error
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1339

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1345
1346
1347
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1345

def labels
  @labels
end

#locationsArray<Google::Apis::SaasservicemgmtV1::Location>

Optional. List of locations that the service is available in. Rollout refers to the list to generate a rollout plan. Corresponds to the JSON property locations



1351
1352
1353
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1351

def locations
  @locations
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/saas/saas" Corresponds to the JSON property name

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1357

def name
  @name
end

#stateString

Output only. State of the Saas. It is always in STATE_ACTIVE state if the application_template is empty. Corresponds to the JSON property state

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1363

def state
  @state
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


1372
1373
1374
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1372

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1379

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1386

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end