Class: Google::Apis::SaasservicemgmtV1::Saas
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Saas
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Saas is a representation of a SaaS service managed by the Producer.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::SaasCondition>
Output only.
-
#create_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::SaasservicemgmtV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::SaasservicemgmtV1::Location>
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Saas
constructor
A new instance of Saas.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Saas
Returns a new instance of Saas.
1221 1222 1223 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1151 1152 1153 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1151 def annotations @annotations end |
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::SaasCondition>
Output only. A set of conditions which indicate the various conditions this
resource can have.
Corresponds to the JSON property conditions
1157 1158 1159 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1157 def conditions @conditions end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1162 1163 1164 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1162 def create_time @create_time end |
#error ⇒ Google::Apis::SaasservicemgmtV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1172 1173 1174 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1172 def error @error end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1179 1180 1181 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1179 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1185 1186 1187 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1185 def labels @labels end |
#locations ⇒ Array<Google::Apis::SaasservicemgmtV1::Location>
Optional. List of locations that the service is available in. Rollout refers
to the list to generate a rollout plan.
Corresponds to the JSON property locations
1191 1192 1193 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1191 def locations @locations end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/saas/saas"
Corresponds to the JSON property name
1197 1198 1199 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1197 def name @name end |
#state ⇒ String
Output only. State of the Saas. It is always in ACTIVE state if the
application_template is empty.
Corresponds to the JSON property state
1203 1204 1205 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1203 def state @state end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1212 1213 1214 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1212 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1219 1220 1221 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1219 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1226 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @error = args[:error] if args.key?(:error) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |