Class: Google::Apis::SaasservicemgmtV1::SaasCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

SaasCondition describes the status of a Saas.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SaasCondition

Returns a new instance of SaasCondition.



1270
1271
1272
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1248

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1253

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1258

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


1263
1264
1265
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1263

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


1268
1269
1270
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1268

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1275
1276
1277
1278
1279
1280
1281
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1275

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end