Class: Google::Apis::SaasservicemgmtV1::SaasCondition
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::SaasCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
SaasCondition describes the status of a Saas.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Required.
-
#message ⇒ String
Required.
-
#reason ⇒ String
Required.
-
#status ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SaasCondition
constructor
A new instance of SaasCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SaasCondition
Returns a new instance of SaasCondition.
1270 1271 1272 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Required. Last time the condition transited from one status to another.
Corresponds to the JSON property lastTransitionTime
1248 1249 1250 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1248 def last_transition_time @last_transition_time end |
#message ⇒ String
Required. Human readable message indicating details about the last transition.
Corresponds to the JSON property message
1253 1254 1255 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1253 def @message end |
#reason ⇒ String
Required. Brief reason for the condition's last transition.
Corresponds to the JSON property reason
1258 1259 1260 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1258 def reason @reason end |
#status ⇒ String
Required. Status of the condition.
Corresponds to the JSON property status
1263 1264 1265 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1263 def status @status end |
#type ⇒ String
Required. Type of the condition.
Corresponds to the JSON property type
1268 1269 1270 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1268 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1275 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |