Class: Google::Apis::SaasservicemgmtV1::SaasRelease
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::SaasRelease
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
SaasRelease is a collection of Releases that are assigned to a UnitGroup. It allows provisioning and updates of UnitGroup, which contains multiple Units of different UnitKinds.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SaasRelease
constructor
A new instance of SaasRelease.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SaasRelease
Returns a new instance of SaasRelease.
1499 1500 1501 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1456 1457 1458 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1456 def annotations @annotations end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1461 1462 1463 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1461 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1468 1469 1470 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1468 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1474 1475 1476 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1474 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/saasReleases/
saasRelease"
Corresponds to the JSON property name
1481 1482 1483 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1481 def name @name end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1490 1491 1492 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1490 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1497 1498 1499 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1497 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1504 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |