Class: Google::Apis::SaasservicemgmtV1::Tenant
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Tenant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Tenant represents the service producer side of an instance of the service created based on a request from a consumer. In a typical scenario a Tenant has a one-to-one mapping with a resource given out to a service consumer. Example: tenant: name: "projects/svc1/locations/loc/tenants/inst-068afff8" consumer_resource: "projects/gshoe/locations/loc/shoes/black-shoe"
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#consumer_resource ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#saas ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tenant
constructor
A new instance of Tenant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tenant
Returns a new instance of Tenant.
1478 1479 1480 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1420 1421 1422 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1420 def annotations @annotations end |
#consumer_resource ⇒ String
Optional. Immutable. A reference to the consumer resource this SaaS Tenant is
representing. The relationship with a consumer resource can be used by App
Lifecycle Manager for retrieving consumer-defined settings and policies such
as maintenance policies (using Unified Maintenance Policy API).
Corresponds to the JSON property consumerResource
1428 1429 1430 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1428 def consumer_resource @consumer_resource end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1433 1434 1435 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1433 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1440 1441 1442 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1440 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1446 1447 1448 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1446 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/tenants/
tenant"
Corresponds to the JSON property name
1453 1454 1455 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1453 def name @name end |
#saas ⇒ String
Required. Immutable. A reference to the Saas that defines the product (managed
service) that the producer wants to manage with App Lifecycle Manager. Part of
the App Lifecycle Manager common data model.
Corresponds to the JSON property saas
1460 1461 1462 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1460 def saas @saas end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1469 1470 1471 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1469 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1476 1477 1478 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1476 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1483 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @consumer_resource = args[:consumer_resource] if args.key?(:consumer_resource) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @saas = args[:saas] if args.key?(:saas) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |