Class: Google::Apis::SaasservicemgmtV1::Tenant

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Tenant represents the service producer side of an instance of the service created based on a request from a consumer. In a typical scenario a Tenant has a one-to-one mapping with a resource given out to a service consumer. Example: tenant: name: "projects/svc1/locations/loc/tenants/inst-068afff8" consumer_resource: "projects/gshoe/locations/loc/shoes/black-shoe"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Tenant

Returns a new instance of Tenant.



1646
1647
1648
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1588
1589
1590
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1588

def annotations
  @annotations
end

#consumer_resourceString

Optional. Immutable. A reference to the consumer resource this SaaS Tenant is representing. The relationship with a consumer resource can be used by App Lifecycle Manager for retrieving consumer-defined settings and policies such as maintenance policies (using Unified Maintenance Policy API). Corresponds to the JSON property consumerResource

Returns:

  • (String)


1596
1597
1598
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1596

def consumer_resource
  @consumer_resource
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1601
1602
1603
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1601

def create_time
  @create_time
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


1608
1609
1610
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1608

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1614
1615
1616
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1614

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/tenants/ tenant" Corresponds to the JSON property name

Returns:

  • (String)


1621
1622
1623
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1621

def name
  @name
end

#saasString

Required. Immutable. A reference to the Saas that defines the product (managed service) that the producer wants to manage with App Lifecycle Manager. Part of the App Lifecycle Manager common data model. Corresponds to the JSON property saas

Returns:

  • (String)


1628
1629
1630
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1628

def saas
  @saas
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


1637
1638
1639
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1637

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


1644
1645
1646
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1644

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1651

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @consumer_resource = args[:consumer_resource] if args.key?(:consumer_resource)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @saas = args[:saas] if args.key?(:saas)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end