Class: Google::Apis::SaasservicemgmtV1::Tenant
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Tenant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Tenant represents the service producer side of an instance of the service created based on a request from a consumer. In a typical scenario a Tenant has a one-to-one mapping with a resource given out to a service consumer. Example: tenant: name: "projects/svc1/locations/loc/tenants/inst-068afff8" consumer_resource: "projects/gshoe/locations/loc/shoes/black-shoe"
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#consumer_resource ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#saas ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tenant
constructor
A new instance of Tenant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tenant
Returns a new instance of Tenant.
1415 1416 1417 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1357 1358 1359 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1357 def annotations @annotations end |
#consumer_resource ⇒ String
Optional. Immutable. A reference to the consumer resource this SaaS Tenant is
representing. The relationship with a consumer resource can be used by App
Lifecycle Manager for retrieving consumer-defined settings and policies such
as maintenance policies (using Unified Maintenance Policy API).
Corresponds to the JSON property consumerResource
1365 1366 1367 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1365 def consumer_resource @consumer_resource end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1370 1371 1372 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1370 def create_time @create_time end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1377 1378 1379 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1377 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1383 1384 1385 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1383 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/tenants/
tenant"
Corresponds to the JSON property name
1390 1391 1392 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1390 def name @name end |
#saas ⇒ String
Required. Immutable. A reference to the Saas that defines the product (managed
service) that the producer wants to manage with App Lifecycle Manager. Part of
the App Lifecycle Manager common data model.
Corresponds to the JSON property saas
1397 1398 1399 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1397 def saas @saas end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1406 1407 1408 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1406 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1413 1414 1415 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1413 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1420 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @consumer_resource = args[:consumer_resource] if args.key?(:consumer_resource) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @saas = args[:saas] if args.key?(:saas) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |