Class: Google::Apis::SaasservicemgmtV1::ToMapping
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::ToMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Input variables whose values will be passed on to dependencies
Instance Attribute Summary collapse
-
#dependency ⇒ String
Required.
-
#ignore_for_lookup ⇒ Boolean
(also: #ignore_for_lookup?)
Optional.
-
#input_variable ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToMapping
constructor
A new instance of ToMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToMapping
Returns a new instance of ToMapping.
1455 1456 1457 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1455 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dependency ⇒ String
Required. Alias of the dependency that the inputVariable will pass its value
to
Corresponds to the JSON property dependency
1441 1442 1443 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1441 def dependency @dependency end |
#ignore_for_lookup ⇒ Boolean Also known as: ignore_for_lookup?
Optional. Tells App Lifecycle Manager if this mapping should be used during
lookup or not
Corresponds to the JSON property ignoreForLookup
1447 1448 1449 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1447 def ignore_for_lookup @ignore_for_lookup end |
#input_variable ⇒ String
Required. Name of the inputVariable on the dependency
Corresponds to the JSON property inputVariable
1453 1454 1455 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1453 def input_variable @input_variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1460 1461 1462 1463 1464 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1460 def update!(**args) @dependency = args[:dependency] if args.key?(:dependency) @ignore_for_lookup = args[:ignore_for_lookup] if args.key?(:ignore_for_lookup) @input_variable = args[:input_variable] if args.key?(:input_variable) end |