Class: Google::Apis::SaasservicemgmtV1::Unit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

A unit of deployment that has its lifecycle via a CRUD API using an actuation engine under the hood (e.g. based on Terraform, Helm or a custom implementation provided by a service producer). A building block of a SaaS Tenant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Unit

Returns a new instance of Unit.



1872
1873
1874
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1711
1712
1713
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1711

def annotations
  @annotations
end

#conditionsArray<Google::Apis::SaasservicemgmtV1::UnitCondition>

Optional. Output only. A set of conditions which indicate the various conditions this resource can have. Corresponds to the JSON property conditions



1717
1718
1719
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1717

def conditions
  @conditions
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1722
1723
1724
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1722

def create_time
  @create_time
end

#dependenciesArray<Google::Apis::SaasservicemgmtV1::UnitDependency>

Optional. Output only. Set of dependencies for this unit. Maximum 10. Corresponds to the JSON property dependencies



1727
1728
1729
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1727

def dependencies
  @dependencies
end

#dependentsArray<Google::Apis::SaasservicemgmtV1::UnitDependency>

Optional. Output only. List of Units that depend on this unit. Unit can only be deprovisioned if this list is empty. Maximum 1000. Corresponds to the JSON property dependents



1733
1734
1735
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1733

def dependents
  @dependents
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1740

def etag
  @etag
end

#flag_revisionsArray<String>

Optional. Output only. Flag revisions used by this Unit. Corresponds to the JSON property flagRevisions

Returns:

  • (Array<String>)


1745
1746
1747
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1745

def flag_revisions
  @flag_revisions
end

#input_variablesArray<Google::Apis::SaasservicemgmtV1::UnitVariable>

Optional. Output only. Indicates the current input variables deployed by the unit Corresponds to the JSON property inputVariables



1751
1752
1753
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1751

def input_variables
  @input_variables
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1757
1758
1759
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1757

def labels
  @labels
end

#maintenanceGoogle::Apis::SaasservicemgmtV1::MaintenanceSettings

Captures requested directives for performing future maintenance on the unit. This includes a request for the unit to skip maintenance for a period of time and remain pinned to its current release as well as controls for postponing maintenance scheduled in future. Corresponds to the JSON property maintenance



1765
1766
1767
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1765

def maintenance
  @maintenance
end

#management_modeString

Optional. Immutable. Indicates whether the Unit life cycle is controlled by the user or by the system. Immutable once created. Corresponds to the JSON property managementMode

Returns:

  • (String)


1771
1772
1773
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1771

def management_mode
  @management_mode
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/units/unit" Corresponds to the JSON property name

Returns:

  • (String)


1777
1778
1779
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1777

def name
  @name
end

#ongoing_operationsArray<String>

Optional. Output only. List of concurrent UnitOperations that are operating on this Unit. Corresponds to the JSON property ongoingOperations

Returns:

  • (Array<String>)


1783
1784
1785
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1783

def ongoing_operations
  @ongoing_operations
end

#output_variablesArray<Google::Apis::SaasservicemgmtV1::UnitVariable>

Optional. Output only. Set of key/value pairs corresponding to output variables from execution of actuation templates. The variables are declared in actuation configs (e.g in helm chart or terraform) and the values are fetched and returned by the actuation engine upon completion of execution. Corresponds to the JSON property outputVariables



1791
1792
1793
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1791

def output_variables
  @output_variables
end

#pending_operationsArray<String>

Optional. Output only. List of pending (wait to be executed) UnitOperations for this unit. Corresponds to the JSON property pendingOperations

Returns:

  • (Array<String>)


1797
1798
1799
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1797

def pending_operations
  @pending_operations
end

#releaseString

Optional. Output only. The current Release object for this Unit. Corresponds to the JSON property release

Returns:

  • (String)


1802
1803
1804
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1802

def release
  @release
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1807
1808
1809
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1807

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Indicates whether the resource location satisfies Zone Separation constraints. This is false by default. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1814
1815
1816
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1814

def satisfies_pzs
  @satisfies_pzs
end

#scheduled_operationsArray<String>

Optional. Output only. List of scheduled UnitOperations for this unit. Corresponds to the JSON property scheduledOperations

Returns:

  • (Array<String>)


1820
1821
1822
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1820

def scheduled_operations
  @scheduled_operations
end

#stateString

Optional. Output only. Current lifecycle state of the resource (e.g. if it's being created or ready to use). Corresponds to the JSON property state

Returns:

  • (String)


1826
1827
1828
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1826

def state
  @state
end

#system_cleanup_atString

Optional. Output only. If set, indicates the time when the system will start removing the unit. Corresponds to the JSON property systemCleanupAt

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1832

def system_cleanup_at
  @system_cleanup_at
end

#system_managed_stateString

Optional. Output only. Indicates the system managed state of the unit. Corresponds to the JSON property systemManagedState

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1837

def system_managed_state
  @system_managed_state
end

#tenantString

Optional. Reference to the Saas Tenant resource this unit belongs to. This for example informs the maintenance policies to use for scheduling future updates on a unit. (optional and immutable once created) Corresponds to the JSON property tenant

Returns:

  • (String)


1844
1845
1846
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1844

def tenant
  @tenant
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


1853
1854
1855
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1853

def uid
  @uid
end

#unit_groupString

Optional. Output only. Reference to the UnitGroup this unit belongs to. Corresponds to the JSON property unitGroup

Returns:

  • (String)


1858
1859
1860
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1858

def unit_group
  @unit_group
end

#unit_kindString

Optional. Reference to the UnitKind this Unit belongs to. Immutable once set. Corresponds to the JSON property unitKind

Returns:

  • (String)


1863
1864
1865
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1863

def unit_kind
  @unit_kind
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


1870
1871
1872
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1870

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1877

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @dependents = args[:dependents] if args.key?(:dependents)
  @etag = args[:etag] if args.key?(:etag)
  @flag_revisions = args[:flag_revisions] if args.key?(:flag_revisions)
  @input_variables = args[:input_variables] if args.key?(:input_variables)
  @labels = args[:labels] if args.key?(:labels)
  @maintenance = args[:maintenance] if args.key?(:maintenance)
  @management_mode = args[:management_mode] if args.key?(:management_mode)
  @name = args[:name] if args.key?(:name)
  @ongoing_operations = args[:ongoing_operations] if args.key?(:ongoing_operations)
  @output_variables = args[:output_variables] if args.key?(:output_variables)
  @pending_operations = args[:pending_operations] if args.key?(:pending_operations)
  @release = args[:release] if args.key?(:release)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduled_operations = args[:scheduled_operations] if args.key?(:scheduled_operations)
  @state = args[:state] if args.key?(:state)
  @system_cleanup_at = args[:system_cleanup_at] if args.key?(:system_cleanup_at)
  @system_managed_state = args[:system_managed_state] if args.key?(:system_managed_state)
  @tenant = args[:tenant] if args.key?(:tenant)
  @uid = args[:uid] if args.key?(:uid)
  @unit_group = args[:unit_group] if args.key?(:unit_group)
  @unit_kind = args[:unit_kind] if args.key?(:unit_kind)
  @update_time = args[:update_time] if args.key?(:update_time)
end