Class: Google::Apis::SaasservicemgmtV1::UnitCondition
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::UnitCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
UnitCondition describes the status of an Unit. UnitCondition is individual components that contribute to an overall state.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Required.
-
#message ⇒ String
Required.
-
#reason ⇒ String
Required.
-
#status ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitCondition
constructor
A new instance of UnitCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitCondition
Returns a new instance of UnitCondition.
1701 1702 1703 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Required. Last time the condition transited from one status to another.
Corresponds to the JSON property lastTransitionTime
1679 1680 1681 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1679 def last_transition_time @last_transition_time end |
#message ⇒ String
Required. Human readable message indicating details about the last transition.
Corresponds to the JSON property message
1684 1685 1686 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1684 def @message end |
#reason ⇒ String
Required. Brief reason for the condition's last transition.
Corresponds to the JSON property reason
1689 1690 1691 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1689 def reason @reason end |
#status ⇒ String
Required. Status of the condition.
Corresponds to the JSON property status
1694 1695 1696 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1694 def status @status end |
#type ⇒ String
Required. Type of the condition.
Corresponds to the JSON property type
1699 1700 1701 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1699 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1706 1707 1708 1709 1710 1711 1712 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1706 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |