Class: Google::Apis::SaasservicemgmtV1::UnitKind
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::UnitKind
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Definition of a Unit. Units belonging to the same UnitKind are managed together; for example they follow the same release model (blueprints, versions etc.) and are typically rolled out together.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#boundary_type ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#default_flag_revisions ⇒ Array<String>
Optional.
-
#default_release ⇒ String
Optional.
-
#dependencies ⇒ Array<Google::Apis::SaasservicemgmtV1::Dependency>
Optional.
-
#etag ⇒ String
Output only.
-
#input_variable_mappings ⇒ Array<Google::Apis::SaasservicemgmtV1::VariableMapping>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#output_variable_mappings ⇒ Array<Google::Apis::SaasservicemgmtV1::VariableMapping>
Optional.
-
#saas ⇒ String
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitKind
constructor
A new instance of UnitKind.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitKind
Returns a new instance of UnitKind.
2217 2218 2219 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
2129 2130 2131 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2129 def annotations @annotations end |
#boundary_type ⇒ String
Optional. Output only. BoundaryType describes the type of boundary the Unit
Kind represents.
Corresponds to the JSON property boundaryType
2135 2136 2137 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2135 def boundary_type @boundary_type end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
2140 2141 2142 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2140 def create_time @create_time end |
#default_flag_revisions ⇒ Array<String>
Optional. Default revisions of flags for this UnitKind. Newly created units
will use the flag default_flag_revisions present at the time of creation.
Corresponds to the JSON property defaultFlagRevisions
2146 2147 2148 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2146 def default_flag_revisions @default_flag_revisions end |
#default_release ⇒ String
Optional. A reference to the Release object to use as default for creating new
units of this UnitKind (optional). If not specified, a new unit must
explicitly reference which release to use for its creation.
Corresponds to the JSON property defaultRelease
2153 2154 2155 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2153 def default_release @default_release end |
#dependencies ⇒ Array<Google::Apis::SaasservicemgmtV1::Dependency>
Optional. Immutable. List of other unit kinds that this release will depend on.
Dependencies will be automatically provisioned if not found. Maximum 10.
Corresponds to the JSON property dependencies
2159 2160 2161 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2159 def dependencies @dependencies end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
2166 2167 2168 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2166 def etag @etag end |
#input_variable_mappings ⇒ Array<Google::Apis::SaasservicemgmtV1::VariableMapping>
Optional. List of inputVariables for this release that will either be
retrieved from a dependency’s outputVariables, or will be passed on to a
dependency’s inputVariables. Maximum 100.
Corresponds to the JSON property inputVariableMappings
2173 2174 2175 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2173 def input_variable_mappings @input_variable_mappings end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
2179 2180 2181 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2179 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/unitKinds/
unitKind"
Corresponds to the JSON property name
2186 2187 2188 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2186 def name @name end |
#output_variable_mappings ⇒ Array<Google::Apis::SaasservicemgmtV1::VariableMapping>
Optional. List of outputVariables for this unit kind will be passed to this
unit's outputVariables. Maximum 100.
Corresponds to the JSON property outputVariableMappings
2192 2193 2194 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2192 def output_variable_mappings @output_variable_mappings end |
#saas ⇒ String
Required. Immutable. A reference to the Saas that defines the product (managed
service) that the producer wants to manage with App Lifecycle Manager. Part of
the App Lifecycle Manager common data model. Immutable once set.
Corresponds to the JSON property saas
2199 2200 2201 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2199 def saas @saas end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
2208 2209 2210 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2208 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
2215 2216 2217 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2215 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2222 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @boundary_type = args[:boundary_type] if args.key?(:boundary_type) @create_time = args[:create_time] if args.key?(:create_time) @default_flag_revisions = args[:default_flag_revisions] if args.key?(:default_flag_revisions) @default_release = args[:default_release] if args.key?(:default_release) @dependencies = args[:dependencies] if args.key?(:dependencies) @etag = args[:etag] if args.key?(:etag) @input_variable_mappings = args[:input_variable_mappings] if args.key?(:input_variable_mappings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @output_variable_mappings = args[:output_variable_mappings] if args.key?(:output_variable_mappings) @saas = args[:saas] if args.key?(:saas) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |