Class: Google::Apis::SaasservicemgmtV1::UnitKind

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Definition of a Unit. Units belonging to the same UnitKind are managed together; for example they follow the same release model (blueprints, versions etc.) and are typically rolled out together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitKind

Returns a new instance of UnitKind.



1834
1835
1836
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/user-guide/annotations Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1752
1753
1754
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1752

def annotations
  @annotations
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1757

def create_time
  @create_time
end

#default_flag_revisionsArray<String>

Optional. Default revisions of flags for this UnitKind. Newly created units will use the flag default_flag_revisions present at the time of creation. Corresponds to the JSON property defaultFlagRevisions

Returns:

  • (Array<String>)


1763
1764
1765
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1763

def default_flag_revisions
  @default_flag_revisions
end

#default_releaseString

Optional. A reference to the Release object to use as default for creating new units of this UnitKind (optional). If not specified, a new unit must explicitly reference which release to use for its creation. Corresponds to the JSON property defaultRelease

Returns:

  • (String)


1770
1771
1772
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1770

def default_release
  @default_release
end

#dependenciesArray<Google::Apis::SaasservicemgmtV1::Dependency>

Optional. Immutable. List of other unit kinds that this release will depend on. Dependencies will be automatically provisioned if not found. Maximum 10. Corresponds to the JSON property dependencies



1776
1777
1778
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1776

def dependencies
  @dependencies
end

#etagString

Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written. Corresponds to the JSON property etag

Returns:

  • (String)


1783
1784
1785
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1783

def etag
  @etag
end

#input_variable_mappingsArray<Google::Apis::SaasservicemgmtV1::VariableMapping>

Optional. List of inputVariables for this release that will either be retrieved from a dependency’s outputVariables, or will be passed on to a dependency’s inputVariables. Maximum 100. Corresponds to the JSON property inputVariableMappings



1790
1791
1792
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1790

def input_variable_mappings
  @input_variable_mappings
end

#labelsHash<String,String>

Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1796
1797
1798
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1796

def labels
  @labels
end

#nameString

Identifier. The resource name (full URI of the resource) following the standard naming scheme: "projects/project/locations/location/unitKinds/ unitKind" Corresponds to the JSON property name

Returns:

  • (String)


1803
1804
1805
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1803

def name
  @name
end

#output_variable_mappingsArray<Google::Apis::SaasservicemgmtV1::VariableMapping>

Optional. List of outputVariables for this unit kind will be passed to this unit's outputVariables. Maximum 100. Corresponds to the JSON property outputVariableMappings



1809
1810
1811
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1809

def output_variable_mappings
  @output_variable_mappings
end

#saasString

Required. Immutable. A reference to the Saas that defines the product (managed service) that the producer wants to manage with App Lifecycle Manager. Part of the App Lifecycle Manager common data model. Immutable once set. Corresponds to the JSON property saas

Returns:

  • (String)


1816
1817
1818
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1816

def saas
  @saas
end

#uidString

Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4. Corresponds to the JSON property uid

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1825

def uid
  @uid
end

#update_timeString

Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value. Corresponds to the JSON property updateTime

Returns:

  • (String)


1832
1833
1834
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1832

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1839

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_flag_revisions = args[:default_flag_revisions] if args.key?(:default_flag_revisions)
  @default_release = args[:default_release] if args.key?(:default_release)
  @dependencies = args[:dependencies] if args.key?(:dependencies)
  @etag = args[:etag] if args.key?(:etag)
  @input_variable_mappings = args[:input_variable_mappings] if args.key?(:input_variable_mappings)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @output_variable_mappings = args[:output_variable_mappings] if args.key?(:output_variable_mappings)
  @saas = args[:saas] if args.key?(:saas)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end