Class: Google::Apis::SaasservicemgmtV1::UnitOperation
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::UnitOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
UnitOperation encapsulates the intent of changing/interacting with the service component represented by the specific Unit. Multiple UnitOperations can be created (requested) and scheduled in the future, however only one will be allowed to execute at a time (that can change in the future for non-mutating operations). UnitOperations allow different actors interacting with the same unit to focus only on the change they have requested. This is a base object that contains the common fields in all unit operations. Next: 22
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#cancel ⇒ Boolean
(also: #cancel?)
Optional.
-
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitOperationCondition>
Optional.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#deprovision ⇒ Google::Apis::SaasservicemgmtV1::Deprovision
Deprovision is the unit operation that deprovision the underlying resources represented by a Unit.
-
#engine_state ⇒ String
Optional.
-
#error_category ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#flag_update ⇒ Google::Apis::SaasservicemgmtV1::FlagUpdate
FlagUpdate is a UnitOperation that pushes new flag values to Units.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#parent_unit_operation ⇒ String
Optional.
-
#provision ⇒ Google::Apis::SaasservicemgmtV1::Provision
Provision is the unit operation that provision the underlying resources represented by a Unit.
-
#rollout ⇒ String
Optional.
-
#schedule ⇒ Google::Apis::SaasservicemgmtV1::Schedule
A time specification to schedule the maintenance.
-
#state ⇒ String
Optional.
-
#uid ⇒ String
Output only.
-
#unit ⇒ String
Required.
-
#update_time ⇒ String
Output only.
-
#upgrade ⇒ Google::Apis::SaasservicemgmtV1::Upgrade
Upgrade is the unit operation that upgrades a provisioned unit, which may also include the underlying resources represented by a Unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitOperation
constructor
A new instance of UnitOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitOperation
Returns a new instance of UnitOperation.
2002 2003 2004 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Annotations is an unstructured key-value map stored with a resource
that may be set by external tools to store and retrieve arbitrary metadata.
They are not queryable and should be preserved when modifying objects. More
info: https://kubernetes.io/docs/user-guide/annotations
Corresponds to the JSON property annotations
1872 1873 1874 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1872 def annotations @annotations end |
#cancel ⇒ Boolean Also known as: cancel?
Optional. When true, attempt to cancel the operation. Cancellation may fail if
the operation is already executing. (Optional)
Corresponds to the JSON property cancel
1878 1879 1880 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1878 def cancel @cancel end |
#conditions ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitOperationCondition>
Optional. Output only. A set of conditions which indicate the various
conditions this resource can have.
Corresponds to the JSON property conditions
1885 1886 1887 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1885 def conditions @conditions end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1890 1891 1892 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1890 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp when the resource was marked for deletion (deletion
is an asynchronous operation).
Corresponds to the JSON property deleteTime
1896 1897 1898 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1896 def delete_time @delete_time end |
#deprovision ⇒ Google::Apis::SaasservicemgmtV1::Deprovision
Deprovision is the unit operation that deprovision the underlying resources
represented by a Unit. Can only execute if the Unit is currently provisioned.
Corresponds to the JSON property deprovision
1902 1903 1904 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1902 def deprovision @deprovision end |
#engine_state ⇒ String
Optional. Output only. The engine state for on-going deployment engine
operation(s). This field is opaque for external usage.
Corresponds to the JSON property engineState
1908 1909 1910 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1908 def engine_state @engine_state end |
#error_category ⇒ String
Optional. Output only. UnitOperationErrorCategory describe the error category.
Corresponds to the JSON property errorCategory
1913 1914 1915 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1913 def error_category @error_category end |
#etag ⇒ String
Output only. An opaque value that uniquely identifies a version or generation
of a resource. It can be used to confirm that the client and server agree on
the ordering of a resource being written.
Corresponds to the JSON property etag
1920 1921 1922 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1920 def etag @etag end |
#flag_update ⇒ Google::Apis::SaasservicemgmtV1::FlagUpdate
FlagUpdate is a UnitOperation that pushes new flag values to Units.
Corresponds to the JSON property flagUpdate
1925 1926 1927 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1925 def flag_update @flag_update end |
#labels ⇒ Hash<String,String>
Optional. The labels on the resource, which can be used for categorization.
similar to Kubernetes resource labels.
Corresponds to the JSON property labels
1931 1932 1933 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1931 def labels @labels end |
#name ⇒ String
Identifier. The resource name (full URI of the resource) following the
standard naming scheme: "projects/project/locations/location/
unitOperations/unitOperation"
Corresponds to the JSON property name
1938 1939 1940 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1938 def name @name end |
#parent_unit_operation ⇒ String
Optional. Reference to parent resource: UnitOperation. If an operation needs
to create other operations as part of its workflow, each of the child
operations should have this field set to the parent. This can be used for
tracing. (Optional)
Corresponds to the JSON property parentUnitOperation
1946 1947 1948 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1946 def parent_unit_operation @parent_unit_operation end |
#provision ⇒ Google::Apis::SaasservicemgmtV1::Provision
Provision is the unit operation that provision the underlying resources
represented by a Unit. Can only execute if the Unit is not currently
provisioned.
Corresponds to the JSON property provision
1953 1954 1955 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1953 def provision @provision end |
#rollout ⇒ String
Optional. Specifies which rollout created this Unit Operation. This cannot be
modified and is used for filtering purposes only. If a dependent unit and unit
operation are created as part of another unit operation, they will use the
same rolloutId.
Corresponds to the JSON property rollout
1961 1962 1963 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1961 def rollout @rollout end |
#schedule ⇒ Google::Apis::SaasservicemgmtV1::Schedule
A time specification to schedule the maintenance.
Corresponds to the JSON property schedule
1966 1967 1968 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1966 def schedule @schedule end |
#state ⇒ String
Optional. Output only. UnitOperationState describes the current state of the
unit operation.
Corresponds to the JSON property state
1972 1973 1974 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1972 def state @state end |
#uid ⇒ String
Output only. The unique identifier of the resource. UID is unique in the time
and space for this resource within the scope of the service. It is typically
generated by the server on successful creation of a resource and must not be
changed. UID is used to uniquely identify resources with resource name reuses.
This should be a UUID4.
Corresponds to the JSON property uid
1981 1982 1983 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1981 def uid @uid end |
#unit ⇒ String
Required. Immutable. The Unit a given UnitOperation will act upon.
Corresponds to the JSON property unit
1986 1987 1988 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1986 def unit @unit end |
#update_time ⇒ String
Output only. The timestamp when the resource was last updated. Any change to
the resource made by users must refresh this value. Changes to a resource made
by the service should refresh this value.
Corresponds to the JSON property updateTime
1993 1994 1995 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 1993 def update_time @update_time end |
#upgrade ⇒ Google::Apis::SaasservicemgmtV1::Upgrade
Upgrade is the unit operation that upgrades a provisioned unit, which may also
include the underlying resources represented by a Unit. Can only execute if
the Unit is currently provisioned.
Corresponds to the JSON property upgrade
2000 2001 2002 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2000 def upgrade @upgrade end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2007 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @cancel = args[:cancel] if args.key?(:cancel) @conditions = args[:conditions] if args.key?(:conditions) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @deprovision = args[:deprovision] if args.key?(:deprovision) @engine_state = args[:engine_state] if args.key?(:engine_state) @error_category = args[:error_category] if args.key?(:error_category) @etag = args[:etag] if args.key?(:etag) @flag_update = args[:flag_update] if args.key?(:flag_update) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent_unit_operation = args[:parent_unit_operation] if args.key?(:parent_unit_operation) @provision = args[:provision] if args.key?(:provision) @rollout = args[:rollout] if args.key?(:rollout) @schedule = args[:schedule] if args.key?(:schedule) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @unit = args[:unit] if args.key?(:unit) @update_time = args[:update_time] if args.key?(:update_time) @upgrade = args[:upgrade] if args.key?(:upgrade) end |