Class: Google::Apis::SaasservicemgmtV1::UnitOperationCondition
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::UnitOperationCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
UnitOperationCondition describes the status of an Unit Operation. UnitOperationCondition is individual components that contribute to an overall state.
Instance Attribute Summary collapse
-
#last_transition_time ⇒ String
Required.
-
#message ⇒ String
Required.
-
#reason ⇒ String
Required.
-
#status ⇒ String
Required.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UnitOperationCondition
constructor
A new instance of UnitOperationCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UnitOperationCondition
Returns a new instance of UnitOperationCondition.
2447 2448 2449 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_transition_time ⇒ String
Required. Last time the condition transited from one status to another.
Corresponds to the JSON property lastTransitionTime
2425 2426 2427 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2425 def last_transition_time @last_transition_time end |
#message ⇒ String
Required. Human readable message indicating details about the last transition.
Corresponds to the JSON property message
2430 2431 2432 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2430 def @message end |
#reason ⇒ String
Required. Brief reason for the condition's last transition.
Corresponds to the JSON property reason
2435 2436 2437 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2435 def reason @reason end |
#status ⇒ String
Required. Status of the condition.
Corresponds to the JSON property status
2440 2441 2442 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2440 def status @status end |
#type ⇒ String
Required. Type of the condition.
Corresponds to the JSON property type
2445 2446 2447 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2445 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2452 def update!(**args) @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time) @message = args[:message] if args.key?(:message) @reason = args[:reason] if args.key?(:reason) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |