Class: Google::Apis::SaasservicemgmtV1::UnitOperationCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

UnitOperationCondition describes the status of an Unit Operation. UnitOperationCondition is individual components that contribute to an overall state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnitOperationCondition

Returns a new instance of UnitOperationCondition.



2063
2064
2065
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_transition_timeString

Required. Last time the condition transited from one status to another. Corresponds to the JSON property lastTransitionTime

Returns:

  • (String)


2041
2042
2043
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2041

def last_transition_time
  @last_transition_time
end

#messageString

Required. Human readable message indicating details about the last transition. Corresponds to the JSON property message

Returns:

  • (String)


2046
2047
2048
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2046

def message
  @message
end

#reasonString

Required. Brief reason for the condition's last transition. Corresponds to the JSON property reason

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2051

def reason
  @reason
end

#statusString

Required. Status of the condition. Corresponds to the JSON property status

Returns:

  • (String)


2056
2057
2058
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2056

def status
  @status
end

#typeString

Required. Type of the condition. Corresponds to the JSON property type

Returns:

  • (String)


2061
2062
2063
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2061

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2068
2069
2070
2071
2072
2073
2074
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2068

def update!(**args)
  @last_transition_time = args[:last_transition_time] if args.key?(:last_transition_time)
  @message = args[:message] if args.key?(:message)
  @reason = args[:reason] if args.key?(:reason)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end