Class: Google::Apis::SaasservicemgmtV1::Upgrade
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::Upgrade
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Upgrade is the unit operation that upgrades a provisioned unit, which may also include the underlying resources represented by a Unit. Can only execute if the Unit is currently provisioned.
Instance Attribute Summary collapse
-
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional.
-
#release ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Upgrade
constructor
A new instance of Upgrade.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Upgrade
Returns a new instance of Upgrade.
2125 2126 2127 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_variables ⇒ Array<Google::Apis::SaasservicemgmtV1::UnitVariable>
Optional. Set of input variables. Maximum 100. (optional)
Corresponds to the JSON property inputVariables
2118 2119 2120 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2118 def input_variables @input_variables end |
#release ⇒ String
Optional. Reference to the Release object to use for the Unit. (optional).
Corresponds to the JSON property release
2123 2124 2125 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2123 def release @release end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2130 2131 2132 2133 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2130 def update!(**args) @input_variables = args[:input_variables] if args.key?(:input_variables) @release = args[:release] if args.key?(:release) end |