Class: Google::Apis::SaasservicemgmtV1::VariableMapping
- Inherits:
-
Object
- Object
- Google::Apis::SaasservicemgmtV1::VariableMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb
Overview
Mapping of input variables to their respective output variable for depedenencies
Instance Attribute Summary collapse
-
#from ⇒ Google::Apis::SaasservicemgmtV1::FromMapping
Output variables whose values will be passed on to dependencies Corresponds to the JSON property
from. -
#to ⇒ Google::Apis::SaasservicemgmtV1::ToMapping
Input variables whose values will be passed on to dependencies Corresponds to the JSON property
to. -
#variable ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VariableMapping
constructor
A new instance of VariableMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VariableMapping
Returns a new instance of VariableMapping.
2256 2257 2258 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#from ⇒ Google::Apis::SaasservicemgmtV1::FromMapping
Output variables whose values will be passed on to dependencies
Corresponds to the JSON property from
2244 2245 2246 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2244 def from @from end |
#to ⇒ Google::Apis::SaasservicemgmtV1::ToMapping
Input variables whose values will be passed on to dependencies
Corresponds to the JSON property to
2249 2250 2251 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2249 def to @to end |
#variable ⇒ String
Required. name of the variable
Corresponds to the JSON property variable
2254 2255 2256 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2254 def variable @variable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2261 2262 2263 2264 2265 |
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2261 def update!(**args) @from = args[:from] if args.key?(:from) @to = args[:to] if args.key?(:to) @variable = args[:variable] if args.key?(:variable) end |