Class: Google::Apis::SaasservicemgmtV1::VariableMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/saasservicemgmt_v1/classes.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb,
lib/google/apis/saasservicemgmt_v1/representations.rb

Overview

Mapping of input variables to their respective output variable for depedenencies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VariableMapping

Returns a new instance of VariableMapping.



2570
2571
2572
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fromGoogle::Apis::SaasservicemgmtV1::FromMapping

Output variables whose values will be passed on to dependencies Corresponds to the JSON property from



2558
2559
2560
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2558

def from
  @from
end

#toGoogle::Apis::SaasservicemgmtV1::ToMapping

Input variables whose values will be passed on to dependencies Corresponds to the JSON property to



2563
2564
2565
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2563

def to
  @to
end

#variableString

Required. name of the variable Corresponds to the JSON property variable

Returns:

  • (String)


2568
2569
2570
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2568

def variable
  @variable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2575
2576
2577
2578
2579
# File 'lib/google/apis/saasservicemgmt_v1/classes.rb', line 2575

def update!(**args)
  @from = args[:from] if args.key?(:from)
  @to = args[:to] if args.key?(:to)
  @variable = args[:variable] if args.key?(:variable)
end